summaryrefslogtreecommitdiffstats
path: root/ui/gfx/win
diff options
context:
space:
mode:
authordbeam@chromium.org <dbeam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-18 20:03:44 +0000
committerdbeam@chromium.org <dbeam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-18 20:03:44 +0000
commit2aadf21d2ff4882cb94510e4107067a70a928850 (patch)
tree8acbc4f186e6fc73a20292b2baca8efc954d47cb /ui/gfx/win
parentdf97969962d83bf8ad962bc3d46b824ebeee4af0 (diff)
downloadchromium_src-2aadf21d2ff4882cb94510e4107067a70a928850.zip
chromium_src-2aadf21d2ff4882cb94510e4107067a70a928850.tar.gz
chromium_src-2aadf21d2ff4882cb94510e4107067a70a928850.tar.bz2
Prefix string16 with base:: in ui/.
R=sky@chromium.org, tsepez@chromium.org BUG=329295 Review URL: https://codereview.chromium.org/117983002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@241625 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/gfx/win')
-rw-r--r--ui/gfx/win/hwnd_util.cc2
-rw-r--r--ui/gfx/win/hwnd_util.h4
-rw-r--r--ui/gfx/win/window_impl.cc2
3 files changed, 4 insertions, 4 deletions
diff --git a/ui/gfx/win/hwnd_util.cc b/ui/gfx/win/hwnd_util.cc
index fec39d4..4f06066 100644
--- a/ui/gfx/win/hwnd_util.cc
+++ b/ui/gfx/win/hwnd_util.cc
@@ -70,7 +70,7 @@ MSVC_ENABLE_OPTIMIZE();
} // namespace
-string16 GetClassName(HWND window) {
+base::string16 GetClassName(HWND window) {
// GetClassNameW will return a truncated result (properly null terminated) if
// the given buffer is not large enough. So, it is not possible to determine
// that we got the entire class name if the result is exactly equal to the
diff --git a/ui/gfx/win/window_impl.cc b/ui/gfx/win/window_impl.cc
index 7f0c232..3ca3f90 100644
--- a/ui/gfx/win/window_impl.cc
+++ b/ui/gfx/win/window_impl.cc
@@ -97,7 +97,7 @@ ATOM ClassRegistrar::RetrieveClassAtom(const ClassInfo& class_info) {
}
// No class found, need to register one.
- string16 name = string16(WindowImpl::kBaseClassName) +
+ base::string16 name = base::string16(WindowImpl::kBaseClassName) +
base::IntToString16(registered_count_++);
WNDCLASSEX window_class;
diff --git a/ui/gfx/win/hwnd_util.h b/ui/gfx/win/hwnd_util.h
index 472dacc..2afd660 100644
--- a/ui/gfx/win/hwnd_util.h
+++ b/ui/gfx/win/hwnd_util.h
@@ -15,8 +15,8 @@ class Point;
class Size;
// A version of the GetClassNameW API that returns the class name in an
-// string16. An empty result indicates a failure to get the class name.
-GFX_EXPORT string16 GetClassName(HWND hwnd);
+// base::string16. An empty result indicates a failure to get the class name.
+GFX_EXPORT base::string16 GetClassName(HWND hwnd);
// Useful for subclassing a HWND. Returns the previous window procedure.
GFX_EXPORT WNDPROC SetWindowProc(HWND hwnd, WNDPROC wndproc);